@@ -482,7 +482,7 @@ class Application extends ApplicationConfig
         $this->TPL->cache_dir    = $this->tpl_root . '/cache';
 
         if ($debug = $this->getparam('DEBUG')) {
-            $this->setsession('DEBUG',$debug);
+            $this->setSession('DEBUG',$debug);
         }
     }
 
@@ -902,6 +902,22 @@ class Application extends ApplicationConfig
     }
 
 
+    /**
+     * clearMsg
+     *
+     * Set $MSG according to the message symbol.
+     *
+     * Fetches the message from the file $confdir/ERRORMSG
+     *
+     * @access public
+     * @param string $msg_sym symbol
+     */
+    function clearMsg ()
+    {
+        $this->TPL->clearAssign('MSG');
+    }
+
+
     /**
      * setSkin
      *
