@@ -90,9 +90,9 @@ class ApplicationConfig
         if (! $fd = @fopen ($cfile, "r")) {
             $dir = $_SERVER['SCRIPT_FILENAME'];
             $script_path = dirname($dir);
-	        error_log('Cannot open config file: '.$script_path. '/'.$cfile);
+	        error_log('WARNING: Cannot open config file: '.$script_path. '/'.$cfile);
             if ($die_on_error) {
-                die ("Cannot open config file.\n");
+                die ("ERROR: Cannot open config file.\n");
             }
             else {
                 return $this->parameters;
