@@ -56,19 +56,19 @@ $rest_data['URL']  = $RESTconf->getConfig('BASE_URL',$base_url_mainconf);
 $rest_data['USER'] = $RESTconf->getConfig('REST_USER','benno2');
 $rest_data['PASS'] = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
 
-$User = new User($userid);
-$User->setRestData($rest_data);  // set defaults from config
+$USER = new User($userid);
+$USER->setRestData($rest_data);  // set defaults from config
 try {
     if ($authscript && is_readable($authscript)) {
-        $User->loadExternal($authscript,$passwd);
+        $USER->loadExternal($authscript,$passwd);
     }
     else {
         $App->log("Cannot read \"$authscript\". Fallback authentication.");
-        $User->load();
+        $USER->load();
         // check authentication
-        if ($User->password != md5($passwd)) {
+        if ($USER->password != md5($passwd)) {
             // Authentication error -> redirect to login
-            $App->log('Authentication of '.$User->id.' failed');
+            $App->log('Authentication of '.$USER->id.' failed');
             $App->redirect('default',array('MSG'=>'ERR_AUTH'));
         }
     }
@@ -80,45 +80,44 @@ catch (Exception $e) {
 }
 
 // LOGIN SUCCESSFUL
-$App->log('Authentication of '.$User->id. ' successful',1);
+$App->log('Authentication of '.$USER->id. ' successful',1);
 
 // initialize backend
-$archive_list = $User->getArchives();
-$archive = end($archive_list);
-$FilterList = Filter::FetchList($User);
+$FilterList = Filter::FetchList($USER);
 $filterString = '';
 foreach ($FilterList as $Filter) {
     $filterString .= $Filter->getString();
 }
 
-$rest_data = $User->getRestData();
+$rest_data = $USER->getRestData();
 $Backend = new Backend($rest_data['URL'],$rest_data['USER'],$rest_data['PASS'],
                        $filterString);
 
-// initialize session
-$App->setSession('ACCESS_LEVEL',$User->getAuthzLevel());
-$App->setSession('USER',$User);
-$App->setSession('Backend',$Backend);   // store backend for this session
-$App->setSession('archive',$archive);   // store current archive
-$App->setSession('FilterList',$FilterList);
-
 // defaults for extended search form
 $timerange = $App->getConfig('DEFAULT_TIMERANGE');
 $ExtQuery = new Query('empty');
 $App->setSession('ExtQuery',$ExtQuery);
 
-$App->setSession('QueryList',StoredQuery::FetchList($User->id));
+$App->setSession('QueryList',StoredQuery::FetchList($USER->id));
+
+// list of assigened archives
+$archive_list = $USER->getArchives();
 
 // restore state of last session
 try {
     // searchMask
-    $AppState = new AppState($User->id);
+    $AppState = new AppState($USER->id);
     $searchMaskState = $AppState->getValue('searchMaskState','Simple');
     $App->setSession('searchMaskState',$searchMaskState);
 
+    // current archive
+    if (!$archive = $AppState->getValue('archive')) {
+        $archive = end($archive_list);
+    }
+
     // Language
     if ($App->getParam('interfaceLanguage')) {
-        $AppState->setValue('userLanguage',$App->getParam('interfaceLanguage'));
+        $AppState->saveValue('userLanguage',$App->getParam('interfaceLanguage'));
         $App->setLang($App->getParam('interfaceLanguage'));
     }
     else {
@@ -132,13 +131,30 @@ catch (Exception $e) {
     $App->log('Error loading application state: '.$e->getMessage());
 }
 
+// initialize session
+$App->setSession('ACCESS_LEVEL',$USER->getAuthzLevel());
+$App->setSession('USER',$USER);
+$App->setSession('Backend',$Backend);   // store backend for this session
+$App->setSession('archive',$archive);   // store current archive
+$App->setSession('FilterList',$FilterList);
+
+
 // set language on change and after login for 32 days
 setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
 
-// redirect after login
-if (!$redirect = $App->getSession('LOGIN_REDIRECT')) {
-    $redirect = 'greeting';
+
+if ($redirect = $App->getSession('LOGIN_REDIRECT')) {
+    // redirect to permalink
+    $App->redirect($redirect);
+}
+else {
+    $login_showlast = $App->getConfig('LOGIN_SHOWLAST',-1);
+    if ($login_showlast > -1) {
+        $App->redirect('showCurrent');
+    }
+    else {
+        $App->redirect('greeting');
+    }
 }
-$App->redirect($redirect);
 
 ?>
