@@ -36,8 +36,8 @@ $extForm   = $App->getParam('ext');
 $queryName = $App->getParam('queryName');
 $queryName = urldecode($queryName);         // "..." will be url-encoded
 
-$User = $App->getSession('USER');
-$queryId = uniqid($User->id);
+$USER = $App->getSession('USER');
+$queryId = uniqid($USER->id);
 
 $ExtQuery = new Query($queryId,$archive,
         $extForm['text'],
@@ -56,9 +56,9 @@ $ExtQuery->setSortOrder($sortOrder);
 
 try {
     // store query
-    $StoredQuery = new StoredQuery($queryId,$User->id,$queryName,$ExtQuery);
+    $StoredQuery = new StoredQuery($queryId,$USER->id,$queryName,$ExtQuery);
     $StoredQuery->save();
-    $QueryList = StoredQuery::FetchList($User->id);
+    $QueryList = StoredQuery::FetchList($USER->id);
     $App->setSession('QueryList',$QueryList);
 }
 catch (Exception $e) {
