@@ -65,7 +65,7 @@ $App->assign('DATEPICKER_POPUP',$App->getConfig('DATEPICKER_POPUP','both'));
 
 
 // load mail in content area
-if ($sessionMailId) {
+if ($sessionMailId  || $show_greeting) {
     $App->assign('showMailContent','TRUE');
     $App->assign('currentMailId',$sessionMailId);
 }
